#
# spec file for package ode
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define so_maj  8
%define lname   libode%{so_maj}
Name:           ode
Version:        0.16.5
Release:        1.3
Summary:        Open Dynamics Engine Library
License:        BSD-3-Clause OR LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://ode.org/
Source0:        https://bitbucket.org/odedevs/ode/downloads/%{name}-%{version}.tar.gz
Source1:        ode-config.1
Patch0:         ode-iso-cpp.patch
BuildRequires:  Mesa-devel
BuildRequires:  freeglut-devel
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%package -n %{lname}
Summary:        Open Dynamics Engine Library development files
Group:          System/Libraries

%description -n %{lname}
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%package devel
Summary:        Open Dynamics Engine Library development files
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}
Provides:       libode-devel = %{version}

%description devel
ODE is an open source, high performance library for simulating rigid
body dynamics. It is fully featured, stable, mature and platform
independent with an easy to use C/C++ API. It has advanced joint types
and integrated collision detection with friction. ODE is useful for
simulating vehicles, objects in virtual reality environments and
virtual creatures. It is currently used in many computer games, 3D
authoring tools and simulation tools.

%prep
%autosetup -p1 -n ode-%{version}

%build
#autoreconf -fi
CFLAGS="%{optflags} -fno-strict-aliasing"
CXXFLAGS="$CFLAGS"
export CFLAGS CXXFLAGS
export X_LIBS="-lX11"
%configure --enable-shared --disable-static --enable-double-precision
%make_build

%install
%make_install
mkdir -p %{buildroot}%{_mandir}/man1
gzip -c9 %{SOURCE1} | tee -a %{buildroot}%{_mandir}/man1/ode-config.1.gz
find %{buildroot} -type f -name "*.la" -delete -print

%ifarch %{ix86}
# Fail.
%else

%check
%make_build check
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%license LICENSE.TXT
%{_libdir}/libode.so.%{so_maj}.*

%files devel
%{_bindir}/ode-config
%{_mandir}/man1/ode-config.1%{?ext_man}
%{_includedir}/ode
%{_libdir}/libode.so
%{_libdir}/libode.so.%{so_maj}
%{_libdir}/pkgconfig/*.pc

%changelog
* Tue Mar 26 2024 Hannes Braun <apple.hannes@gmail.com>
- Update to 0.16.5:
  * Autotools build scripts, when configured with "--enable-libccd",
    will now assign all the relevant colliders to the libccd.
    Before, it used to keep default collider for Box-Cylinder pair and
    that was inconsistent with other configuration methods (CMake and
    premake4). To obtain the old behavior configure as
    "--enable-libccd --with-box-cylinder=default".
* Mon Feb 26 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  PatchN.
* Sat Sep 30 2023 Hannes Braun <apple.hannes@gmail.com>
- Update to 0.16.4:
  * dJointAddPUTorques() was added to replace orphaned declaration of
    dJointAddPUTorque().
  * Fixed a missing break in a switch statement in demo_jointPU.cpp while
    handling gravity switching request.
  * Fixed wrong face index being returned in convex-trimesh libCCD
    collision check routine.
  * Fixed use of potentially outdated AABBs in GIIMPACT cylinder-trimesh
    collision check routine.
* Sun Jan 15 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.3:
  * compatibility corrections
* Thu Sep 17 2020 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.16.2: minor bug and compatibility fixes
* Sun Mar 29 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 0.16.1: minor bug and compatibility fixes
* Thu May 30 2019 Jannik Seiler <seil0@mosad.xyz>
- Changed License to BSD-3-Clause OR LGPL-2.1-or-later
* Sat Mar 23 2019 Jannik Seiler <seil0@mosad.xyz>
- Update to 0.16
  * The commentary from 11/05/2018 was wrong. The constraints were not
    reset to their natural order and remained randomized.
    The other thing that was missing was full contraint reorder without
    separation into independent and dependent ones. The algorithm doesn't
    converge without it well.
  * An incorrect optimization to Jacobian Copy building code from #1938
    that resulted in corrupt data in multi-threaded execution mode was
    fixed.
  * An unintended change from commit #1898 has been reverted.
    The QuickStep used to solve with randomized constraint order
    each 8th iteration. The other iterations, the constraints
    were reset to their natural order, as generated, with the dependent
    constraints gathered in reverse order at end (the reverse order is
    somehow important). With the commit #1898 the constraints were
    randomly reordered each 8th iteration but then remained
    in that randomized order and only were re-randomized on subsequent
    multiples of 8.
  * CMake support for project file generation has been added.
  * dxHashSpace::collide() has been changed to fault host program
    if scene gets too large and causes integer overflow.
  * Memory and pointer size integer type use has been changed so that
    internal typedefs are used instead of "_t" suffixed types.
  * Introduction of cooperative algorithms API.
    L*D*LT cooperative factorization and linear equation system
    cooperative solving have been implemented.
  * AtomicReadReorderBarrier, AtomicStore, AtomicStorePointer functions
    have been added and some atomic function implementations have been
    improved in OU.
- adjusted ode-iso-cpp.patch
- build with --enable-double-precision
* Thu Nov  9 2017 aavindraa@gmail.com
- Update to 0.15.2:
  * Fixed: A bug with dWorldStep assigning both body feedbacks into
    the first body variables fixed
- Includes changes from 0.15.1:
  * Changed: dSTATIC_ARRAY_SIZE() macro has been added
  * code refactoring, cleanup, optimizations
- Includes changes from 0.15, 0.14, 0.13.1:
  * Changed: dSTATIC_ARRAY_SIZE() macro has been added
  * Changed: Project generation options changed to enable built-in
    multithreaded threading by default
  * Changed: dWorldStep threaded execution extended to final steps
    on constraint force application and body position updates
  * New: dAddVectorScaledVector3() function has been added
  * New: CCD_ATAN2() macro added for libccd
  * New: dAddThreeScaledVectors3() function added in the odemath.h
  * Deprecations:
    + dGeomTriMeshDataGetBuff (use dGeomTriMeshDataGet)
    + dGeomTriMeshDataSetBuff (use dGeomTriMeshDataSet)
    + ddGeomTriMeshDataPreprocess (use GeomTriMeshDataPreprocess2)
  * Changed: Trimesh-Convex edge contact normals have been changed
    to retain their inclination along edges as generated by libCCD
  * Changed: A finer control over OU features implemented and OU
    basic features have been made available by default
  * Fixed: An access beyond the edges array has been fixed in the
    case if last edge was a boundary one
  * Fixed: A bug fixed with HashSpace calling big boxes collision
    twice (both straight and reverse geometries order)
- For the full list of changes, see:
  * https://bitbucket.org/odedevs/ode/compare/0.15.2%%0D0.13
- cleanup with spec-cleaner
- move to new bitbucket url
- use %%make_install macro
* Sun Jun 18 2017 rpm@fthiessen.de
- Added ode-iso-cpp.patch to fix build with new gcc.
* Thu May 26 2016 dap.darkness@gmail.com
- Update to 0.13:
  * Stable, implicit gyroscopic forces.
  * New joint: transmission joint.
  * Contacts now have rolling friction.
  * Removed the need for defining dSINGLE/dDOUBLE.
  * New joint: Double Ball (AKA "distance joint").
  * New joint: Double Hinge.
  * Threaded execution support interface added (experimental).
  * Many bugs were fixed.
- General clean-up via `spec-cleaner`.
- Source tag was fixed up to use the upstream download URL.
- License tag was fixed. Thanks to @AndreasStieger.
- BuildRequires tags were fixed up.
- Project should have the same name as upstream & pkgconfig.
- Added simple man page for ode-config.
- Added `make check` section (fails for i586).
* Sun Feb 19 2012 jengelh@medozas.de
- Use proper LIBS variable for slipping in X11
  (Libs in LDFLAGS may not have any effect due to importance of
  linking order)
* Mon Nov 21 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Call configure properly to put libs where they are supposed to be
- Use %%_smp_mflags for parallel building
- Produce shared libraries
* Sat Nov 19 2011 seife+obs@b1-systems.com
- update to 0.11.1
  * lots of new functions and bugfixes, see CHANGELOG.txt
  * add pkgconfig file
- fix build for > 11.4 (add -lX11 explicitly)
- use $RPM_OPT_FLAGS for building
* Mon Aug 11 2008 sndirsch@suse.de
- update to 0.10.1
  * New function: dJointSetPistonAnchorOffset
  * Add new function dJointSetHingeAxisDelta
  * Fix problem with dJointGetPistonPosition and
    dJointGetPistonPositionRate when the joint is attached to only
    a body 2. The sign was inversed.
  * Update the slider joint to have the same behavior as the other
    joint when there is only a body2 attached to it.
  * Rename the new function dJointSetHingeAxisDelta to
    dJointSetHingeAxisOffset. This will remove confusion with the
    old function dJointSetHingeAnchorDelta.
  * Bug fix: Max Correcting Vel behavior is now the same as before
    0.10.
* Sat Jul 19 2008 sndirsch@suse.de
- update to 0.10
  * current stable release
* Wed Nov 21 2007 sndirsch@suse.de
- update to 0.9
  * latest stable release
* Thu May 24 2007 sndirsch@suse.de
- added -devel package to make rpmlint happy
* Thu May 10 2007 sndirsch@suse.de
- updated to 0.8
* Thu Mar 29 2007 coolo@suse.de
- fix BuildRequires (unzip)
* Fri Oct 20 2006 sndirsch@suse.de
- updated to 0.7
* Mon Jun  5 2006 sndirsch@suse.de
- updated to 0.6-rc3
  * Added Convex primitive collision code,
    currently only convex-sphere and convex-plane work
  * Added program to test trimesh vs sphere: ode/test/test_basket
  * Added new autogenerated Visual Studio projects, with Premake scripts
  * Added plane/cyl intersection test
  * Renamed CCylinder to Capsule
  * Added support for geom offsets.
  * Removed LIBTOOL from autotools since it was not really required.
  * Added a target to build ODE as a shared library, this shared
    library gets build alongside the static one, no flags required.
  * dRandInt changed for a non-double all-int version.
  * mics minor fixes and improvements.
  * Fixed segmentation fault with OPCODE on 64 bits systems.
  * Fixed timer.cpp compiler error on x86-64 using GCC.
  * Added trimesh preprocessing to mark unneeded edges and verts.  Also
    added support for preprocessed info to the ccylinder-trimesh
    collider.
  * Important AMotors bugfix
  * Assorted small bugfixes and tweaks for
    trimesh_{box,ccylinder,trimesh} collisions
  * added functions to joint.cpp to allow joint attachment to moving
    geoms.
  * added malloc-based memory allocation in step.cpp & lcp.cpp (turned
    on with a #define switch in common.h)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Nov 25 2005 sndirsch@suse.de
- added -fno-strict-aliasing to fix build
* Thu Nov 10 2005 sndirsch@suse.de
- created package
